==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BMCDetailsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<A>{
  public BMCDetailsFluentImpl() {
  }
  public BMCDetailsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance) {
    this.withAddress(instance.getAddress()); 
    this.withCredentialsName(instance.getCredentialsName()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String address;
  private java.lang.String credentialsName;
  private java.lang.Boolean disableCertificateVerification;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAddress() {
    return this.address;
  }
  public A withAddress(java.lang.String address) {
    this.address=address; return (A) this;
  }
  public java.lang.Boolean hasAddress() {
    return this.address != null;
  }
  
  /**
   * Method is deprecated. use withAddress instead.
   */
  @java.lang.Deprecated
  public A withNewAddress(java.lang.String arg0) {
    return (A)withAddress(new String(arg0));
  }
  public java.lang.String getCredentialsName() {
    return this.credentialsName;
  }
  public A withCredentialsName(java.lang.String credentialsName) {
    this.credentialsName=credentialsName; return (A) this;
  }
  public java.lang.Boolean hasCredentialsName() {
    return this.credentialsName != null;
  }
  
  /**
   * Method is deprecated. use withCredentialsName instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialsName(java.lang.String arg0) {
    return (A)withCredentialsName(new String(arg0));
  }
  public java.lang.Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  public A withDisableCertificateVerification(java.lang.Boolean disableCertificateVerification) {
    this.disableCertificateVerification=disableCertificateVerification; return (A) this;
  }
  public java.lang.Boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BMCDetailsFluentImpl that = (BMCDetailsFluentImpl) o;
    if (address != null ? !address.equals(that.address) :that.address != null) return false;
    if (credentialsName != null ? !credentialsName.equals(that.credentialsName) :that.credentialsName != null) return false;
    if (disableCertificateVerification != null ? !disableCertificateVerification.equals(that.disableCertificateVerification) :that.disableCertificateVerification != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  credentialsName,  disableCertificateVerification,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BMCDetailsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<A>{
  public BMCDetailsFluentImpl() {
  }
  public BMCDetailsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance) {
    this.withAddress(instance.getAddress()); 
    this.withCredentialsName(instance.getCredentialsName()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String address;
  private java.lang.String credentialsName;
  private java.lang.Boolean disableCertificateVerification;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAddress() {
    return this.address;
  }
  public A withAddress(java.lang.String address) {
    this.address=address; return (A) this;
  }
  public java.lang.Boolean hasAddress() {
    return this.address != null;
  }
  
  /**
   * Method is deprecated. use withAddress instead.
   */
  @java.lang.Deprecated
  public A withNewAddress(java.lang.String arg0) {
    return (A)withAddress(new String(arg0));
  }
  public java.lang.String getCredentialsName() {
    return this.credentialsName;
  }
  public A withCredentialsName(java.lang.String credentialsName) {
    this.credentialsName=credentialsName; return (A) this;
  }
  public java.lang.Boolean hasCredentialsName() {
    return this.credentialsName != null;
  }
  
  /**
   * Method is deprecated. use withCredentialsName instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialsName(java.lang.String arg0) {
    return (A)withCredentialsName(new String(arg0));
  }
  public java.lang.Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  public A withDisableCertificateVerification(java.lang.Boolean disableCertificateVerification) {
    this.disableCertificateVerification=disableCertificateVerification; return (A) this;
  }
  public java.lang.Boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BMCDetailsFluentImpl that = (BMCDetailsFluentImpl) o;
    if (address != null ? !address.equals(that.address) :that.address != null) return false;
    if (credentialsName != null ? !credentialsName.equals(that.credentialsName) :that.credentialsName != null) return false;
    if (disableCertificateVerification != null ? !disableCertificateVerification.equals(that.disableCertificateVerification) :that.disableCertificateVerification != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  credentialsName,  disableCertificateVerification,  additionalProperties,  super.hashCode());
  }
  
}
